@@ -29,7 +29,7 @@ billboarder(data = prod_par_filiere) %>%
   bb_legend(show = FALSE) %>% 
   bb_labs(
     title = "French hydraulic production",
-    caption = "Data source: RTE (https://opendata.rte-france.com)"
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
   )
 
 ## ----barchart-dodge-----------------------------------------------------------
@@ -53,7 +53,7 @@ billboarder() %>%
   bb_legend(position = "inset", inset = list(anchor = "top-right")) %>% 
   bb_labs(
     title = "Renewable energy production",
-    caption = "Data source: RTE (https://opendata.rte-france.com)"
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
   )
 
 ## ----barchart-stacked---------------------------------------------------------
@@ -83,7 +83,7 @@ billboarder() %>%
   bb_legend(position = "inset", inset = list(anchor = "top-right")) %>% 
   bb_labs(
     title = "Renewable energy production",
-    caption = "Data source: RTE (https://opendata.rte-france.com)"
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
   )
 
 ## ----scatter------------------------------------------------------------------
@@ -100,7 +100,6 @@ billboarder() %>%
   bb_x_grid(show = TRUE) %>%
   bb_y_grid(show = TRUE)
 
-
 ## ----scatter-bubble-----------------------------------------------------------
 billboarder(data = mtcars) %>% 
   bb_scatterplot(
@@ -128,8 +127,20 @@ nuclear2016 <- data.frame(
 # pie chart !
 billboarder() %>% 
   bb_piechart(data = nuclear2016) %>% 
-  bb_labs(title = "Share of nuclear power in France in 2016",
-          caption = "Data source: RTE (https://opendata.rte-france.com)")
+  bb_pie(
+    label = list(
+      line = list(
+        show = TRUE,
+        distance = 30,
+        text = TRUE
+      )
+    )
+  ) %>% 
+  bb_legend(show = FALSE) %>% 
+  bb_labs(
+    title = "Share of nuclear power in France in 2016",
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
+  )
 
 ## ----donut--------------------------------------------------------------------
 billboarder() %>% 
@@ -137,11 +148,16 @@ billboarder() %>%
   bb_donut(
     title = "Share of nuclear\nin France",
     label = list(
-      format = JS("function(value, ratio, id) {	return id + ': ' + d3.format('.0%')(ratio);}")
+      format = JS("function(value, ratio, id) {	return d3.format('.0%')(ratio);}"),
+      line = list(
+        show = TRUE,
+        distance = 30,
+        text = TRUE
+      )
     )
   ) %>% 
   bb_legend(show = FALSE) %>% 
-  bb_labs(caption = "Data source: RTE (https://opendata.rte-france.com)")
+  bb_labs(caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)")
 
 ## ----lines-date---------------------------------------------------------------
 library(billboarder)
@@ -161,9 +177,11 @@ billboarder() %>%
   bb_colors_manual("consommation" = "firebrick", "production" = "forestgreen") %>% 
   bb_legend(position = "right") %>% 
   bb_subchart(show = TRUE, size = list(height = 30)) %>% 
-  bb_labs(title = "Monthly electricity consumption and production in France (2007 - 2017)",
-          y = "In megawatt (MW)",
-          caption = "Data source: RTE (https://opendata.rte-france.com)")
+  bb_labs(
+    title = "Monthly electricity consumption and production in France (2007 - 2017)",
+    y = "In megawatt (MW)",
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
+  )
 
 ## ----lines-zoom1--------------------------------------------------------------
 billboarder() %>% 
@@ -181,9 +199,11 @@ billboarder() %>%
     type = "drag",
     resetButton = list(text = "Unzoom")
   ) %>% 
-  bb_labs(title = "Monthly electricity consumption and production in France (2007 - 2017)",
-          y = "In megawatt (MW)",
-          caption = "Data source: RTE (https://opendata.rte-france.com)")
+  bb_labs(
+    title = "Monthly electricity consumption and production in France (2007 - 2017)",
+    y = "In megawatt (MW)",
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
+  )
 
 ## ----lines-time---------------------------------------------------------------
 library(billboarder)
@@ -224,9 +244,11 @@ billboarder() %>%
       list(value = as.numeric(sun$sunset)*1000, text = "sunset")
     )
   ) %>% 
-  bb_labs(title = "Solar production (2017-06-12)",
-          y = "In megawatt (MW)",
-          caption = "Data source: RTE (https://opendata.rte-france.com)")
+  bb_labs(
+    title = "Solar production (2017-06-12)",
+    y = "In megawatt (MW)",
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
+  )
 
 ## ----area-stacked-------------------------------------------------------------
 library(billboarder)
@@ -249,9 +271,11 @@ billboarder() %>%
     opacity = 0.8
   ) %>% 
   bb_y_axis(min = 0, padding = 0) %>% 
-  bb_labs(title = "Renewable energy production (2017-06-12)",
-          y = "In megawatt (MW)",
-          caption = "Data source: RTE (https://opendata.rte-france.com)")
+  bb_labs(
+    title = "Renewable energy production (2017-06-12)",
+    y = "In megawatt (MW)",
+    caption = "Data source: RTE (https://opendata.reseaux-energies.fr/)"
+  )
 
 ## ----lines-range--------------------------------------------------------------
 # Generate data
@@ -312,3 +336,53 @@ billboarder() %>%
     )
   )
 
+## ----radar-single-------------------------------------------------------------
+data("avengers_wide")
+billboarder() %>%
+  bb_radarchart(
+    data = avengers_wide[, 1:2]
+  )
+
+## ----radar-multiple-----------------------------------------------------------
+data("avengers")
+billboarder() %>%
+  bb_radarchart(
+    data = avengers, 
+    mapping = bbaes(x = axis, y = value, group = group)
+  )
+
+## ----gauge-1------------------------------------------------------------------
+billboarder() %>% 
+  bb_gaugechart(value = 50, color = "#112446")
+
+## ----gauge-2------------------------------------------------------------------
+bauge(round(sample.int(100, 1)), subtitle = "of total")
+
+## ----gauge-multiple-----------------------------------------------------------
+billboarder() %>%
+  bb_gaugechart(
+    value = c(15, 30),
+    name = c("A", "B"),
+    color = c("steelblue", "firebrick")
+  ) %>% 
+  bb_gauge(max = 60) %>% 
+  bb_data(
+    labels = list(colors = "#FFF")
+  )
+
+## ----treemap-1----------------------------------------------------------------
+data("mpg", package = "ggplot2")
+billboarder() %>% 
+  bb_treemapchart(
+    data = table(manufacturer = mpg$manufacturer), 
+    mapping = aes(x = manufacturer, y = Freq),
+    label = list(show = TRUE, threshold = 0.03),
+    tile = "binary" # or "slice" or "dice"
+  ) %>% 
+  bb_data(
+    labels = list(colors = "#FFF")
+  ) %>% 
+  bb_color(
+    palette = colorRampPalette(c("#08519C", "#9ECAE1"))(15) #15 = n manufacturer
+  )
+
